from .autocomplete import AutocompleteResource  # noqa: F401
from .config import ConfigResource  # noqa: F401
from .html import HTMLResource  # noqa: F401
from .job import JobResource, JobDetailResource  # noqa: F401
from .login import LoginResource  # noqa: F401
from .logout import LogoutResource  # noqa: F401
from .notebook import NotebookResource, NotebookDetailResource  # noqa: F401
from .register import RegisterResource  # noqa: F401
from .report import ReportResource, ReportDetailResource  # noqa: F401
from .static import StaticResource  # noqa: F401
from .scheduler import SchedulerResource  # noqa: F401
from .status import StatusResource  # noqa: F401
