<!DOCTYPE html>
<html lang="en">
<head>
  <title>Paperboy</title>
  <link rel="stylesheet" type="text/css" href="{{baseurl}}static/fonts/fonts.css">
  <link rel="stylesheet" type="text/css" href="{{baseurl}}static/css/login.css">
  <link href="{{baseurl}}static/css/font-awesome.min.css" rel="stylesheet">
  <link href='https://fonts.googleapis.com/css?family=Roboto' rel='stylesheet'>
  <script>
    document.baseurl = '{{baseurl}}';
    document.apiurl = '{{apiurl}}';
</script>
</head>
<body>
  <style>
  /* has to be here for parameterizing */
  div.background {
  position:absolute;
  height:100%;
  width: 100%;
  background: url({{baseurl}}static/img/paperboy.jpg) no-repeat center center fixed;
  -webkit-background-size: cover;
  -moz-background-size: cover;
  -o-background-size: cover;
  background-size: cover;
  -webkit-filter: blur(10px) brightness(.2);
  -moz-filter: blur(10px) brightness(.2);
  -o-filter:  blur(10px) brightness(.2);
  -ms-filter: blur(10px) brightness(.2);
  filter: blur(10px) brightness(.2);
}

@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 300;
  src: local('Open Sans Light'), local('OpenSans-Light'), url('{{baseurl}}static/fonts/mem5YaGs126MiZpBA-UN_r8OUuhs.ttf') format('truetype');
}
@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 400;
  src: local('Open Sans Regular'), local('OpenSans-Regular'), url('{{baseurl}}static/fonts/mem8YaGs126MiZpBA-UFVZ0e.ttf') format('truetype');
}
@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 600;
  src: local('Open Sans SemiBold'), local('OpenSans-SemiBold'), url('{{baseurl}}static/fonts/mem5YaGs126MiZpBA-UNirkOUuhs.ttf') format('truetype');
}
@font-face {
  font-family: 'Open Sans Condensed';
  font-style: normal;
  font-weight: 300;
  src: local('Open Sans Condensed Light'), local('OpenSansCondensed-Light'), url('{{baseurl}}static/fonts/z7NFdQDnbTkabZAIOl9il_O6KJj73e7Ff1GhDuXMQg.ttf') format('truetype');
}
@font-face {
  font-family: 'Open Sans Condensed';
  font-style: normal;
  font-weight: 700;
  src: local('Open Sans Condensed Bold'), local('OpenSansCondensed-Bold'), url('{{baseurl}}static/fonts/z7NFdQDnbTkabZAIOl9il_O6KJj73e7Ff0GmDuXMQg.ttf') format('truetype');
}
</style>
  <div class="background"></div>
    <div class="log-form">
        <h2>Login to your account</h2>
        <form action='{{baseurl}}{{loginurl}}' method='post' enctype="multipart/form-data">
            <input type="text" name="username" placeholder="username" />
            {% if include_password %}
            <input type="password" name="password" placeholder="password" />
            {% endif %}
            <button type="submit" class="btn">Login</button>
            {% if include_register %}
            <br><br>
            <span>No Account?</span>
            <br>
            <button type="button" class="btn" onclick="window.location.href=window.location.href.replace('{{baseurl}}{{loginurl}}', '{{baseurl}}{{registerurl}}');">Register</button>
            {% endif %}
        </form>
    </div>
</body>
</html>