<!DOCTYPE html>
<html lang="en">
<head>
  <title>Paperboy</title>
  <link rel="stylesheet" type="text/css" href="{{baseurl}}static/fonts/fonts.css">
  <link rel="stylesheet" type="text/css" href="{{baseurl}}static/css/login.css">
  <link href="{{baseurl}}static/css/font-awesome.min.css" rel="stylesheet">
  <link href='https://fonts.googleapis.com/css?family=Roboto' rel='stylesheet'>
  <script>
    document.baseurl = '{{baseurl}}';
    document.apiurl = '{{apiurl}}';
</script>
</head>
<body>
  <div class="background"></div>
    <div class="log-form">
        <h2>Register</h2>
        <form action='{{baseurl}}{{registerurl}}' method='post' enctype="multipart/form-data">
            <input type="text" name="username" placeholder="username" />
            {% if include_password %}
            <input type="password" name="password" placeholder="password" />
            {% endif %}
            <button type="submit" class="btn">Register</button>

            <br><br>
            <span>Already have an account?</span>
            <br>
            <button type="button" class="btn" onclick="window.location.href=window.location.href.replace('{{baseurl}}{{registerurl}}', '{{baseurl}}{{loginurl}}');">Login</button>
        </form>
    </div>
</body>
</html>